@@ -75,16 +75,18 @@
 #' @rdname derivatives
 #'
 #' @return A tibble, currently with the following variables:
-#' * `smooth`: the smooth each row refers to,
-#' * `var`: the name of the variable involved in the smooth,
-#' * `data`: values of `var` at which the derivative was evaluated,
-#' * `derivative`: the estimated derivative,
-#' * `se`: the standard error of the estimated derivative,
-#' * `crit`: the critical value such that `derivative` ± `(crit * se)` gives
+#' * `.smooth`: the smooth each row refers to,
+#' * `.by`: the name of any factor by variable involved in the smooth,
+#' * `.fs`: the name of any random factor variable involved in the smooth,
+#' * `.derivative`: the estimated derivative,
+#' * `.se`: the standard error of the estimated derivative,
+#' * `.crit`: the critical value such that `derivative` ± `(crit * se)` gives
 #'   the upper and lower bounds of the requested confidence or simultaneous
 #'   interval (given `level`),
-#' * `lower`: the lower bound of the confidence or simultaneous interval,
-#' * `upper`: the upper bound of the confidence or simultaneous interval.
+#' * `.lower_ci`: the lower bound of the confidence or simultaneous interval,
+#' * `.upper_ci`: the upper bound of the confidence or simultaneous interval.
+#' * plus one or more columns of data containing the values of covariates at
+#'   which the derivative was evaluated.
 #'
 #' @examples
 #'
@@ -328,6 +330,11 @@
     fs_var <- sm_var[-1L]
     sm_var <- sm_var[1L]
   }
+  ## handle sz smooths
+  if (is_sz_smooth(sm)) {
+    fs_var <- sm$fterm
+    sm_var <- sm_var[!sm_var %in% fs_var]
+  }
   sm_lab <- smooth_label(sm)
   want <- grep(sm_lab, colnames(lpmatrix), fixed = TRUE)
   Xi <- lpmatrix * 0 # zero out the Xp matrix
@@ -346,11 +353,14 @@
   fs_var <- if (is.null(fs_var)) {
     rep(NA_character_, nrow(deriv))
   } else {
-    # data[[fs_var]]
-    deriv <- add_column(deriv, {{ fs_var }} := data[[fs_var]],
-      .after = 2L
-    )
-    rep(fs_var, nrow(deriv))
+    for (i in seq_along(fs_var)) {
+      add_var <- fs_var[i]
+      deriv <- add_column(
+        deriv, {{ add_var }} := data[[add_var]],
+        .after = 2L
+      )
+    }
+    rep(paste(fs_var, collapse = ":"), nrow(deriv))
   }
   deriv <- add_column(deriv, .fs = fs_var, .after = 2L)
 
@@ -1096,8 +1106,8 @@
 #' * `.focal`: the name of the variable for which the partial derivative was
 #'   evaluated,
 #' * `.derivative`: the estimated partial derivative,
-#' * `.lower_ci`: the lower bound of the confidence or simultaneous interval,
-#' * `.upper_ci`: the upper bound of the confidence or simultaneous interval,
+#' * `.lower_ci`: the lower bound of the confidence or interval,
+#' * `.upper_ci`: the upper bound of the confidence or interval,
 #' * additional columns containing the covariate values at which the derivative
 #'   was evaluated.
 #'
@@ -1370,7 +1380,7 @@
 }
 
 #' @importFrom tidyr pivot_wider
-#' @importFrom dplyr mutate case_match
+#' @importFrom dplyr mutate
 #' @importFrom tidyselect matches
 `compute_y_fdiff_2` <- function(samples, type, eps = 1e-7) {
   samples <- samples |>
