@@ -52,7 +52,7 @@ test_that("term argument is deprecated in basis()", {
 test_that("basis() works with a scam", {
   # skip(message = "This needs fixing as something in scam changed")
   skip_on_cran()
-  expect_silent(bs <- basis(m_scam, "s(x2)"))
+  expect_silent(bs <- basis(m_scam, select = "s(x2)"))
   expect_s3_class(bs, "basis")
   expect_named(bs, c(bs_nms, "x2"))
 
