@@ -13,7 +13,7 @@ test_that("test data_sim() produces tibbles", {
 })
 
 test_that("test data_sim() reproduces reference output", {
-  skip_on_ci()
+  # skip_on_ci() # testing without as moved to mac os x
   skip_on_cran()
   for (i in names(ref_sims)) {
     expect_equal(new_sims[[!!(i)]], ref_sims[[!!(i)]])
@@ -22,7 +22,7 @@ test_that("test data_sim() reproduces reference output", {
 
 test_that("data sim for gfam works", {
   expect_silent(sim <- data_sim("gfam", n = 400, seed = 2))
-  skip_on_ci()
+  # skip_on_ci() # testing without as moved to mac os x
   skip_on_cran()
   expect_snapshot(print(sim))
 })
